@@ -4,6 +4,7 @@ use librespot_core::config::SessionConfig;
 use librespot_core::session::Session;
 use librespot_core::session::SessionError;
 use librespot_playback::config::PlayerConfig;
+use librespot_playback::player::NormalisationData;
 use log::{debug, error, info};
 
 use librespot_playback::audio_backend;
@@ -116,13 +117,23 @@ impl Spotify {
             .write()
             .expect("can't writelock worker channel") = Some(tx);
         {
+            let worker_channel = self.channel.clone();
             let cfg = self.cfg.clone();
             let events = self.events.clone();
             let volume = self.volume();
             let credentials = self.credentials.clone();
             let handle = tokio::runtime::Handle::current();
             handle.spawn(async move {
-                Self::worker(events, rx, cfg.clone(), credentials, user_tx, volume).await
+                Self::worker(
+                    worker_channel,
+                    events,
+                    rx,
+                    cfg.clone(),
+                    credentials,
+                    user_tx,
+                    volume,
+                )
+                .await
             });
         }
 
@@ -167,11 +178,11 @@ impl Spotify {
         )
         .expect("Could not create cache");
         debug!("opening spotify session");
-        println!("Connecting to Spotify..");
         Session::connect(session_config, credentials, Some(cache)).await
     }
 
     async fn worker(
+        worker_channel: Arc<RwLock<Option<mpsc::UnboundedSender<WorkerCommand>>>>,
         events: EventManager,
         commands: mpsc::UnboundedReceiver<WorkerCommand>,
         cfg: Arc<config::Config>,
@@ -190,6 +201,9 @@ impl Spotify {
             bitrate: bitrate.unwrap_or(Bitrate::Bitrate320),
             normalisation: cfg.values().volnorm.unwrap_or(false),
             normalisation_pregain: cfg.values().volnorm_pregain.unwrap_or(0.0),
+            normalisation_threshold: NormalisationData::db_to_ratio(
+                PlayerConfig::default().normalisation_threshold,
+            ),
             ..Default::default()
         };
 
@@ -224,6 +238,9 @@ impl Spotify {
         worker.run_loop().await;
 
         error!("worker thread died, requesting restart");
+        *worker_channel
+            .write()
+            .expect("can't writelock worker channel") = None;
         events.send(Event::SessionDied)
     }
 
